@@ -1,30 +1,23 @@
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 #
 #   file: lib/Dist/Zilla/Role/TextTemplater.pm
 #
-
-#pod =encoding UTF-8
-#pod
-#pod =head1 COPYRIGHT AND LICENSE
-#pod
-#pod Copyright © 2015 Van de Bugger
-#pod
-#pod This file is part of perl-Dist-Zilla-Role-TextTemplater.
-#pod
-#pod perl-Dist-Zilla-Role-TextTemplater is free software: you can redistribute it and/or modify it
-#pod under the terms of the GNU General Public License as published by the Free Software Foundation,
-#pod either version 3 of the License, or (at your option) any later version.
-#pod
-#pod perl-Dist-Zilla-Role-TextTemplater is distributed in the hope that it will be useful, but
-#pod WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-#pod PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#pod
-#pod You should have received a copy of the GNU General Public License along with
-#pod perl-Dist-Zilla-Role-TextTemplater. If not, see <http://www.gnu.org/licenses/>.
-#pod
-#pod =cut
-
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   Copyright © 2015, 2016 Van de Bugger.
+#
+#   This file is part of perl-Dist-Zilla-Role-TextTemplater.
+#
+#   perl-Dist-Zilla-Role-TextTemplater is free software: you can redistribute it and/or modify it
+#   under the terms of the GNU General Public License as published by the Free Software Foundation,
+#   either version 3 of the License, or (at your option) any later version.
+#
+#   perl-Dist-Zilla-Role-TextTemplater is distributed in the hope that it will be useful, but
+#   WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+#   PARTICULAR PURPOSE. See the GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License along with
+#   perl-Dist-Zilla-Role-TextTemplater. If not, see <http://www.gnu.org/licenses/>.
+#
+#   ---------------------------------------------------------------------- copyright and license ---
 
 #pod =for :this This is C<Dist::Zilla::Role::TextTemplater> module documentation. Read this if you want to
 #pod have text templating capabilities in your Dist::Zilla plugin.
@@ -33,10 +26,10 @@
 #pod L<manual|Dist::Zilla::Role::TextTemplater::Manual>. General topics like getting source, building, installing, bug
 #pod reporting and some others are covered in the F<README>.
 #pod
-#pod =head1 SYNOPSIS
-#pod
 #pod =for test_synopsis my ( $result, $template, $file );
 #pod
+#pod =head1 SYNOPSIS
+#pod
 #pod     package Dist::Zilla::Plugin::YourPlugin;
 #pod     use Moose;
 #pod     use namespace::autoclean;
@@ -74,7 +67,7 @@ use namespace::autoclean;
 use version 0.77;
 
 # ABSTRACT: Have text templating capabilities in your Dist::Zilla plugin
-our $VERSION = 'v0.8.5_01'; # TRIAL VERSION
+our $VERSION = 'v0.8.5_02'; # TRIAL VERSION
 
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 'v0.6.0' };  # Need `log_errors_in_file`.
 
@@ -104,10 +97,7 @@ my $tt_param = sub {
 #pod
 #pod C<Str|ArrayRef[Str]>, read-only. Default value is C<[ '{{', '}}' ]>.
 #pod
-#pod See C<DELIMITERS> option of L<Text::Template/"fill_in">.
-#pod
-#pod Note: Our default delimiters are "alternative delimiters" for C<Text::Template>. It means escaping
-#pod delimiters with backslash does not work. See L<Text::Template/"Alternative Delimiters">.
+#pod See L<Dist::Zilla::Role::TextTemplater/"Delimiters">.
 #pod
 #pod =cut
 
@@ -141,7 +131,7 @@ has delimiters => (
 #pod
 #pod C<Str>, read-only, optional.
 #pod
-#pod See C<PACKAGE> option of L<Text::Template/"fill_in">.
+#pod See L<Dist::Zilla::Role::TextTemplater/"Package">.
 #pod
 #pod =cut
 
@@ -162,7 +152,7 @@ has package => (
 #pod C<ArrayRef[Str]>, read-only, auto dereferenced. Default value is empty array. Consumers may specify
 #pod alternative default by defining C<_build_prepend> method.
 #pod
-#pod See C<PREPEND> option of L<Text::Template/"fill_in">.
+#pod See L<Dist::Zilla::Role::TextTemplater/"Prepend">.
 #pod
 #pod =cut
 
@@ -384,8 +374,8 @@ around mvp_multivalue_args => sub {
 #pod         { array => $array, hash => $hash, plugin => $self },
 #pod     );
 #pod
-#pod template will have C<@array> (not C<$array>) — array, C<%hash> (not C<$hash>) — hash, and
-#pod C<$plugin> will be (oops!) undefined.
+#pod template will have C<@array> (array, not reference to array), C<%hash> (hash, not reference to
+#pod hash), and C<$plugin> will be (oops!) undefined.
 #pod
 #pod Scalars can be passed either by reference or value:
 #pod
@@ -629,8 +619,8 @@ sub fill_in_file {
 #pod C<-hash>. This is documented feature.
 #pod
 #pod C<Text::Template> recommends to pick a style and stick with it. (BTW, C<Text::Template>
-#pod documentation itself uses all-caps spelling.) This role picked all-lowercase style. This choice
-#pod have subtle consequences. Let us consider an example:
+#pod documentation uses all-caps spelling.) This role picked all-lowercase style. This choice have
+#pod subtle consequences. Let us consider an example:
 #pod
 #pod     $self->fill_in_string( $template, undef, { PACKAGE => 'MY' } );
 #pod
@@ -713,6 +703,17 @@ sub fill_in_file {
 #pod = L<Dist::Zilla::Role::TextTemplate>
 #pod = L<Text::Template>
 #pod
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
+#pod Copyright (C) 2015, 2016 Van de Bugger
+#pod
+#pod License GPLv3+: The GNU General Public License version 3 or later
+#pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
+#pod
+#pod This is free software: you are free to change and redistribute it. There is
+#pod NO WARRANTY, to the extent permitted by law.
+#pod
+#pod
 #pod =cut
 
 # doc/what.pod #
@@ -797,9 +798,8 @@ sub fill_in_file {
 #pod
 #pod     Filling in the template returned undef for:
 #pod
-#pod and file content printed twice. (Yep, if the problem file had 1000 lines, we would have it printed
-#pod twice too.) We do not ever have a file name and have to guess it by the content. Good bug hunting,
-#pod dude.
+#pod and file content printed twice. (Yep, if the file had 1000 lines, we would have it printed twice
+#pod too.) We do not ever have a file name and have to guess it by the content. Good bug hunting, dude.
 #pod
 #pod Ok, let us fix the problem (mistyped closing delimiter in the first line of file
 #pod F<lib/Assa/Manual.pod>) and build the distribution again:
@@ -877,7 +877,7 @@ Dist::Zilla::Role::TextTemplater - Have text templating capabilities in your Dis
 
 =head1 VERSION
 
-Version v0.8.5_01, released on 2016-10-11 20:06 UTC.
+Version v0.8.5_02, released on 2016-11-08 23:14 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
@@ -893,8 +893,33 @@ If you are using a C<TextTemplater>-based plugin, read the
 L<manual|Dist::Zilla::Role::TextTemplater::Manual>. General topics like getting source, building, installing, bug
 reporting and some others are covered in the F<README>.
 
+=for test_synopsis my ( $result, $template, $file );
+
 =head1 SYNOPSIS
 
+    package Dist::Zilla::Plugin::YourPlugin;
+    use Moose;
+    use namespace::autoclean;
+    with 'Dist::Zilla::Role::Plugin';
+    with 'Dist::Zilla::Role::TextTemplater';
+
+    sub method {
+        my $self = shift( @_ );
+        ...;
+        $result = $self->fill_in_string( $template );
+        ...;
+    };
+
+    sub another_method {
+        my $self = shift( @_ );
+        ...;
+        $self->fill_in_file( $file );
+        ...;
+    };
+
+    __PACKAGE__->meta->make_immutable;
+    1;
+
 =head1 DESCRIPTION
 
 The role provides a consuming plugin with C<fill_in_string> and C<fill_in_file> methods and bunch
@@ -911,10 +936,7 @@ whitespaces (result should be two items) to initialize the attribute.
 
 C<Str|ArrayRef[Str]>, read-only. Default value is C<[ '{{', '}}' ]>.
 
-See C<DELIMITERS> option of L<Text::Template/"fill_in">.
-
-Note: Our default delimiters are "alternative delimiters" for C<Text::Template>. It means escaping
-delimiters with backslash does not work. See L<Text::Template/"Alternative Delimiters">.
+See L<Dist::Zilla::Role::TextTemplater/"Delimiters">.
 
 =head2 package
 
@@ -924,7 +946,7 @@ Attribute introduces F<dist.ini> option with the same name.
 
 C<Str>, read-only, optional.
 
-See C<PACKAGE> option of L<Text::Template/"fill_in">.
+See L<Dist::Zilla::Role::TextTemplater/"Package">.
 
 =head2 prepend
 
@@ -935,7 +957,7 @@ Attribute introduces F<dist.ini> multi-value option with the same name.
 C<ArrayRef[Str]>, read-only, auto dereferenced. Default value is empty array. Consumers may specify
 alternative default by defining C<_build_prepend> method.
 
-See C<PREPEND> option of L<Text::Template/"fill_in">.
+See L<Dist::Zilla::Role::TextTemplater/"Prepend">.
 
 =head2 tt_file
 
@@ -1040,8 +1062,8 @@ reference to plugin. If you forget to take references, e. g.:
         { array => $array, hash => $hash, plugin => $self },
     );
 
-template will have C<@array> (not C<$array>) — array, C<%hash> (not C<$hash>) — hash, and
-C<$plugin> will be (oops!) undefined.
+template will have C<@array> (array, not reference to array), C<%hash> (hash, not reference to
+hash), and C<$plugin> will be (oops!) undefined.
 
 Scalars can be passed either by reference or value:
 
@@ -1106,8 +1128,8 @@ all-lowercase, with and without leading dash, e. g.: C<HASH>, C<Hash>, C<hash>,
 C<-hash>. This is documented feature.
 
 C<Text::Template> recommends to pick a style and stick with it. (BTW, C<Text::Template>
-documentation itself uses all-caps spelling.) This role picked all-lowercase style. This choice
-have subtle consequences. Let us consider an example:
+documentation uses all-caps spelling.) This role picked all-lowercase style. This choice have
+subtle consequences. Let us consider an example:
 
     $self->fill_in_string( $template, undef, { PACKAGE => 'MY' } );
 
@@ -1236,9 +1258,8 @@ Oops. What's happened? Where? Why? All we have is a highly unclear error message
 
     Filling in the template returned undef for:
 
-and file content printed twice. (Yep, if the problem file had 1000 lines, we would have it printed
-twice too.) We do not ever have a file name and have to guess it by the content. Good bug hunting,
-dude.
+and file content printed twice. (Yep, if the file had 1000 lines, we would have it printed twice
+too.) We do not ever have a file name and have to guess it by the content. Good bug hunting, dude.
 
 Ok, let us fix the problem (mistyped closing delimiter in the first line of file
 F<lib/Assa/Manual.pod>) and build the distribution again:
@@ -1294,31 +1315,6 @@ C<TextTemplater> allows the end-user to specify C<delimiters>, C<package> and C<
 options in F<dist.ini> file, while C<TextTemplate> allows to specify C<prepend> only
 programmatically, and does I<not> allow to specify C<delimiters> and C<package>.
 
-=for test_synopsis my ( $result, $template, $file );
-
-    package Dist::Zilla::Plugin::YourPlugin;
-    use Moose;
-    use namespace::autoclean;
-    with 'Dist::Zilla::Role::Plugin';
-    with 'Dist::Zilla::Role::TextTemplater';
-
-    sub method {
-        my $self = shift( @_ );
-        ...;
-        $result = $self->fill_in_string( $template );
-        ...;
-    };
-
-    sub another_method {
-        my $self = shift( @_ );
-        ...;
-        $self->fill_in_file( $file );
-        ...;
-    };
-
-    __PACKAGE__->meta->make_immutable;
-    1;
-
 =head1 SEE ALSO
 
 =over 4
@@ -1341,19 +1337,12 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2015 Van de Bugger
+Copyright (C) 2015, 2016 Van de Bugger
 
-This file is part of perl-Dist-Zilla-Role-TextTemplater.
+License GPLv3+: The GNU General Public License version 3 or later
+<http://www.gnu.org/licenses/gpl-3.0.txt>.
 
-perl-Dist-Zilla-Role-TextTemplater is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the Free Software Foundation,
-either version 3 of the License, or (at your option) any later version.
-
-perl-Dist-Zilla-Role-TextTemplater is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-perl-Dist-Zilla-Role-TextTemplater. If not, see <http://www.gnu.org/licenses/>.
+This is free software: you are free to change and redistribute it. There is
+NO WARRANTY, to the extent permitted by law.
 
 =cut
